#PBS -l nodes=8:ppn=8
#PBS -l walltime=13:0:0

from ase.io import read
from gpaw import GPAW, FermiDirac, Mixer, PoissonSolver
from gpaw.utilities import h2gpts
from gpaw.utilities.timing import ParallelTimer

system = read('Au.1415c.traj')
system.center(vacuum=5.0)

calc = GPAW(mode='lcao',
            basis='dzp',
            xc='RPBE',
            txt='gpaw.txt',
            timer=ParallelTimer(),
            nbands=(int(len(system) * 5.7) // 8) * 8,
            convergence=dict(density=1e-5),
            parallel=dict(sl_auto=True),
            #parallel=dict(band=8,
            #              domain=(2, 2, 2),
            #              sl_default=(8, 8, 64)),
            mixer=Mixer(0.05, 7, 200.0),
            occupations=FermiDirac(0.01),
            gpts=h2gpts(0.2, system.get_cell(), idiv=16))

system.set_calculator(calc)
system.get_potential_energy()

#calc.write('dump.gpw')
